Class: Aws::PricingPlanManager::Types::ApprovePaidSubscriptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::ApprovePaidSubscriptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the subscription to approve.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
-
#if_match ⇒ String
The
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse.
Instance Attribute Details
#arn ⇒ String
The ARN of the subscription to approve.
47 48 49 50 51 52 53 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 47 class ApprovePaidSubscriptionInput < Struct.new( :arn, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
A suitable default value is auto-generated. You should normally not need to pass this option.
47 48 49 50 51 52 53 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 47 class ApprovePaidSubscriptionInput < Struct.new( :arn, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The ETag value from a previous GetSubscription or
ListSubscriptions response. This ensures you are approving the
expected version of the subscription.
47 48 49 50 51 52 53 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 47 class ApprovePaidSubscriptionInput < Struct.new( :arn, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |