Class: Aws::PricingPlanManager::Types::AssociateResourcesToSubscriptionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the subscription to add resources to.

Returns:

  • (String)


95
96
97
98
99
100
101
102
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95

class AssociateResourcesToSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the request is handled only once.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


95
96
97
98
99
100
101
102
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95

class AssociateResourcesToSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#if_matchString

The ETag value from a previous GetSubscription or ListSubscriptions response.

Returns:

  • (String)


95
96
97
98
99
100
101
102
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95

class AssociateResourcesToSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

The ARNs of the resources to add to the subscription.

Returns:

  • (Array<String>)


95
96
97
98
99
100
101
102
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95

class AssociateResourcesToSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end