Class: Aws::PricingPlanManager::Types::AssociateResourcesToSubscriptionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::AssociateResourcesToSubscriptionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#e_tag ⇒ String
The updated entity tag for concurrency control.
-
#subscription ⇒ Types::Subscription
The details of the subscription with the newly added resources.
Instance Attribute Details
#e_tag ⇒ String
The updated entity tag for concurrency control.
114 115 116 117 118 119 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 114 class AssociateResourcesToSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |
#subscription ⇒ Types::Subscription
The details of the subscription with the newly added resources.
114 115 116 117 118 119 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 114 class AssociateResourcesToSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |