Class: Aws::PricingPlanManager::Types::CancelSubscriptionChangeOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::CancelSubscriptionChangeOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#e_tag ⇒ String
The updated entity tag for concurrency control.
-
#subscription ⇒ Types::Subscription
The details of the subscription with the pending change removed.
Instance Attribute Details
#e_tag ⇒ String
The updated entity tag for concurrency control.
158 159 160 161 162 163 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 158 class CancelSubscriptionChangeOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |
#subscription ⇒ Types::Subscription
The details of the subscription with the pending change removed.
158 159 160 161 162 163 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 158 class CancelSubscriptionChangeOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |