Class: Aws::PricingPlanManager::Types::CancelSubscriptionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the subscription to cancel.

Returns:

  • (String)


184
185
186
187
188
189
190
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 184

class CancelSubscriptionInput < Struct.new(
  :arn,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the request is handled only once.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


184
185
186
187
188
189
190
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 184

class CancelSubscriptionInput < Struct.new(
  :arn,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#if_matchString

The ETag value from a previous GetSubscription or ListSubscriptions response.

Returns:

  • (String)


184
185
186
187
188
189
190
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 184

class CancelSubscriptionInput < Struct.new(
  :arn,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end