Class: Aws::PricingPlanManager::Types::CancelSubscriptionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::CancelSubscriptionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#e_tag ⇒ String
The updated entity tag for concurrency control.
-
#subscription ⇒ Types::Subscription
The details of the subscription with the pending cancellation.
Instance Attribute Details
#e_tag ⇒ String
The updated entity tag for concurrency control.
204 205 206 207 208 209 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 204 class CancelSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |
#subscription ⇒ Types::Subscription
The details of the subscription with the pending cancellation. For
active subscriptions, a scheduledChange of type CANCELLATION is
included.
204 205 206 207 208 209 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 204 class CancelSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |