Class: Aws::PricingPlanManager::Types::ConflictException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

The request conflicts with the current state of the resource. This typically occurs when the ETag value in the If-Match header does not match the current version of the subscription. Retrieve the latest version and retry.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


225
226
227
228
229
230
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 225

class ConflictException < Struct.new(
  :message,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource that has a conflicting state.

Returns:

  • (String)


225
226
227
228
229
230
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 225

class ConflictException < Struct.new(
  :message,
  :resource_id)
  SENSITIVE = []
  include Aws::Structure
end