Class: Aws::PricingPlanManager::Types::CreateSubscriptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::CreateSubscriptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#approval_mode ⇒ String
Determines whether the subscription requires explicit approval before billing starts.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is handled only once.
-
#plan_family ⇒ String
The pricing plan family to subscribe to, such as
CloudFront. -
#plan_tier ⇒ String
The tier level for the subscription, such as
FREE,PRO,BUSINESS, orPREMIUM. -
#resource_arns ⇒ Array<String>
The ARNs of the resources to include in the subscription.
-
#usage_level ⇒ String
The usage level within the plan tier.
Instance Attribute Details
#approval_mode ⇒ String
Determines whether the subscription requires explicit approval
before billing starts. Set to MANUAL to require a separate
ApprovePaidSubscription call, or IMMEDIATE to activate the
subscription right away. For paid tier plans, this defaults to
MANUAL if not specified. For the FREE plan tier, only
IMMEDIATE is supported, and it is the default.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure that the request is handled only once. If you send the same request with the same client token, the API returns the original response without creating a duplicate subscription.
A suitable default value is auto-generated. You should normally not need to pass this option.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |
#plan_family ⇒ String
The pricing plan family to subscribe to, such as CloudFront.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |
#plan_tier ⇒ String
The tier level for the subscription, such as FREE, PRO,
BUSINESS, or PREMIUM.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
The ARNs of the resources to include in the subscription. Specify one or more supported resources.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |
#usage_level ⇒ String
The usage level within the plan tier. Specify DEFAULT for the base
configuration, or a higher level if your plan tier supports it.
279 280 281 282 283 284 285 286 287 288 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 279 class CreateSubscriptionInput < Struct.new( :plan_family, :plan_tier, :usage_level, :resource_arns, :approval_mode, :client_token) SENSITIVE = [] include Aws::Structure end |