Class: Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN of the subscription to remove resources from.



333
334
335
336
337
338
339
340
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 333

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier that you provide to ensure the request is handled only once.

A suitable default value is auto-generated. You should normally not need to pass this option.



333
334
335
336
337
338
339
340
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 333

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#if_match ⇒ String

The ETag value from a previous GetSubscription or ListSubscriptions response.



333
334
335
336
337
338
339
340
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 333

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arns ⇒ Array<String>

The ARNs of the resources to remove from the subscription. For subscriptions in the CloudFront plan family, you cannot remove the required CloudFront distribution or WAF web ACL.



333
334
335
336
337
338
339
340
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 333

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end