Class: Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#e_tag ⇒ String
The updated entity tag for concurrency control.
-
#subscription ⇒ Types::Subscription
The details of the subscription with the specified resources removed.
Instance Attribute Details
#e_tag ⇒ String
The updated entity tag for concurrency control.
351 352 353 354 355 356 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 351 class DisassociateResourcesFromSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |
#subscription ⇒ Types::Subscription
The details of the subscription with the specified resources removed.
351 352 353 354 355 356 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 351 class DisassociateResourcesFromSubscriptionOutput < Struct.new( :subscription, :e_tag) SENSITIVE = [] include Aws::Structure end |