Class: Aws::PricingPlanManager::Types::ListSubscriptionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

A token that indicates there are more results available. Pass this value in a subsequent ListSubscriptions request to retrieve the next page of results.

Returns:

  • (String)


429
430
431
432
433
434
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 429

class ListSubscriptionsOutput < Struct.new(
  :subscription_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_summaries ⇒ Array<Types::SubscriptionSummary>

The list of subscription summaries for the calling account.

Returns:



429
430
431
432
433
434
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 429

class ListSubscriptionsOutput < Struct.new(
  :subscription_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end