Class: Aws::PricingPlanManager::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
The specified subscription was not found. Verify that the ARN is correct and that the subscription belongs to your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
The identifier of the resource that was not found.
Instance Attribute Details
#message ⇒ String
446 447 448 449 450 451 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 446 class ResourceNotFoundException < Struct.new( :message, :resource_id) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the resource that was not found.
446 447 448 449 450 451 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 446 class ResourceNotFoundException < Struct.new( :message, :resource_id) SENSITIVE = [] include Aws::Structure end |