Class: Aws::PricingPlanManager::Types::ScheduledChange

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

A pending change on a subscription that takes effect at the end of the current billing period, such as a tier downgrade or cancellation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_typeString

The type of pending change. Possible values are DOWNGRADE (a tier change to a lower level) and CANCELLATION (subscription termination).

Returns:

  • (String)


480
481
482
483
484
485
486
487
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480

class ScheduledChange < Struct.new(
  :change_type,
  :effective_date,
  :plan_tier,
  :usage_level)
  SENSITIVE = []
  include Aws::Structure
end

#effective_dateTime

The date and time when the change takes effect, in ISO 8601 format. This value is populated after the change is confirmed by the billing system.

Returns:

  • (Time)


480
481
482
483
484
485
486
487
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480

class ScheduledChange < Struct.new(
  :change_type,
  :effective_date,
  :plan_tier,
  :usage_level)
  SENSITIVE = []
  include Aws::Structure
end

#plan_tierString

For downgrades, the tier level that the subscription will change to. Not present for cancellations.

Returns:

  • (String)


480
481
482
483
484
485
486
487
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480

class ScheduledChange < Struct.new(
  :change_type,
  :effective_date,
  :plan_tier,
  :usage_level)
  SENSITIVE = []
  include Aws::Structure
end

#usage_levelString

For downgrades, the target usage level after the change takes effect.

Returns:

  • (String)


480
481
482
483
484
485
486
487
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480

class ScheduledChange < Struct.new(
  :change_type,
  :effective_date,
  :plan_tier,
  :usage_level)
  SENSITIVE = []
  include Aws::Structure
end