Class: Aws::PricingPlanManager::Types::SubscriptionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Summary information for a flat-rate pricing subscription, as returned by list operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that uniquely identifies this subscription.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time when the subscription was created, in ISO 8601 format.

Returns:

  • (Time)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#e_tagString

The entity tag for concurrency control. Pass this value in the If-Match header when making changes to this subscription.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#plan_familyString

The pricing plan family for the subscription, such as CloudFront.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#plan_tierString

The current tier level of the pricing plan.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

The ARNs of the AWS resources covered by this subscription.

Returns:

  • (Array<String>)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_changeTypes::ScheduledChange

A pending change that will take effect at the end of the current billing period, if any.



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the subscription.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

A human-readable explanation of the current status, present when additional context is available.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time when the subscription was last modified, in ISO 8601 format.

Returns:

  • (Time)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end

#usage_levelString

The usage level within the plan tier.

Returns:

  • (String)


627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627

class SubscriptionSummary < Struct.new(
  :arn,
  :plan_family,
  :plan_tier,
  :usage_level,
  :scheduled_change,
  :status,
  :status_reason,
  :resource_arns,
  :created_at,
  :updated_at,
  :e_tag)
  SENSITIVE = []
  include Aws::Structure
end