Class: Aws::PricingPlanManager::Types::UpdateSubscriptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::UpdateSubscriptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the subscription to update.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
-
#if_match ⇒ String
The
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse. -
#plan_tier ⇒ String
The new tier level for the subscription.
-
#usage_level ⇒ String
The usage level within the plan tier.
Instance Attribute Details
#arn ⇒ String
The ARN of the subscription to update.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 686 class UpdateSubscriptionInput < Struct.new( :arn, :plan_tier, :usage_level, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
A suitable default value is auto-generated. You should normally not need to pass this option.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 686 class UpdateSubscriptionInput < Struct.new( :arn, :plan_tier, :usage_level, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The ETag value from a previous GetSubscription or
ListSubscriptions response. This ensures you are updating the
expected version of the subscription.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 686 class UpdateSubscriptionInput < Struct.new( :arn, :plan_tier, :usage_level, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#plan_tier ⇒ String
The new tier level for the subscription.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 686 class UpdateSubscriptionInput < Struct.new( :arn, :plan_tier, :usage_level, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#usage_level ⇒ String
The usage level within the plan tier. Specify DEFAULT for the base
configuration. If omitted, the usage level is reset to the default.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 686 class UpdateSubscriptionInput < Struct.new( :arn, :plan_tier, :usage_level, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |