Class: Aws::PricingPlanManager::Types::AssociateResourcesToSubscriptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::AssociateResourcesToSubscriptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the subscription to add resources to.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
-
#if_match ⇒ String
The
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse. -
#resource_arns ⇒ Array<String>
The ARNs of the resources to add to the subscription.
Instance Attribute Details
#arn ⇒ String
The ARN of the subscription to add resources to.
95 96 97 98 99 100 101 102 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95 class AssociateResourcesToSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
A suitable default value is auto-generated. You should normally not need to pass this option.
95 96 97 98 99 100 101 102 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95 class AssociateResourcesToSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The ETag value from a previous GetSubscription or
ListSubscriptions response.
95 96 97 98 99 100 101 102 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95 class AssociateResourcesToSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
The ARNs of the resources to add to the subscription.
95 96 97 98 99 100 101 102 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 95 class AssociateResourcesToSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |