Class: Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pricingplanmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the subscription to remove resources from.

Returns:

  • (String)


331
332
333
334
335
336
337
338
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the request is handled only once.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


331
332
333
334
335
336
337
338
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#if_matchString

The ETag value from a previous GetSubscription or ListSubscriptions response.

Returns:

  • (String)


331
332
333
334
335
336
337
338
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnsArray<String>

The ARNs of the resources to remove from the subscription. For subscriptions in the CloudFront plan family, you cannot remove the required CloudFront distribution or WAF web ACL.

Returns:

  • (Array<String>)


331
332
333
334
335
336
337
338
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331

class DisassociateResourcesFromSubscriptionInput < Struct.new(
  :arn,
  :resource_arns,
  :if_match,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end