Class: Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::DisassociateResourcesFromSubscriptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN of the subscription to remove resources from.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
-
#if_match ⇒ String
The
ETagvalue from a previousGetSubscriptionorListSubscriptionsresponse. -
#resource_arns ⇒ Array<String>
The ARNs of the resources to remove from the subscription.
Instance Attribute Details
#arn ⇒ String
The ARN of the subscription to remove resources from.
331 332 333 334 335 336 337 338 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331 class DisassociateResourcesFromSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the request is handled only once.
A suitable default value is auto-generated. You should normally not need to pass this option.
331 332 333 334 335 336 337 338 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331 class DisassociateResourcesFromSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#if_match ⇒ String
The ETag value from a previous GetSubscription or
ListSubscriptions response.
331 332 333 334 335 336 337 338 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331 class DisassociateResourcesFromSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
The ARNs of the resources to remove from the subscription. For subscriptions in the CloudFront plan family, you cannot remove the required CloudFront distribution or WAF web ACL.
331 332 333 334 335 336 337 338 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 331 class DisassociateResourcesFromSubscriptionInput < Struct.new( :arn, :resource_arns, :if_match, :client_token) SENSITIVE = [] include Aws::Structure end |