Class: Aws::PricingPlanManager::Types::ScheduledChange
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::ScheduledChange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
A pending change on a subscription that takes effect at the end of the current billing period, such as a tier downgrade or cancellation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_type ⇒ String
The type of pending change.
-
#effective_date ⇒ Time
The date and time when the change takes effect, in ISO 8601 format.
-
#plan_tier ⇒ String
For downgrades, the tier level that the subscription will change to.
-
#usage_level ⇒ String
For downgrades, the target usage level after the change takes effect.
Instance Attribute Details
#change_type ⇒ String
The type of pending change. Possible values are DOWNGRADE (a tier
change to a lower level) and CANCELLATION (subscription
termination).
480 481 482 483 484 485 486 487 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480 class ScheduledChange < Struct.new( :change_type, :effective_date, :plan_tier, :usage_level) SENSITIVE = [] include Aws::Structure end |
#effective_date ⇒ Time
The date and time when the change takes effect, in ISO 8601 format. This value is populated after the change is confirmed by the billing system.
480 481 482 483 484 485 486 487 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480 class ScheduledChange < Struct.new( :change_type, :effective_date, :plan_tier, :usage_level) SENSITIVE = [] include Aws::Structure end |
#plan_tier ⇒ String
For downgrades, the tier level that the subscription will change to. Not present for cancellations.
480 481 482 483 484 485 486 487 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480 class ScheduledChange < Struct.new( :change_type, :effective_date, :plan_tier, :usage_level) SENSITIVE = [] include Aws::Structure end |
#usage_level ⇒ String
For downgrades, the target usage level after the change takes effect.
480 481 482 483 484 485 486 487 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 480 class ScheduledChange < Struct.new( :change_type, :effective_date, :plan_tier, :usage_level) SENSITIVE = [] include Aws::Structure end |