Class: Aws::PricingPlanManager::Types::SubscriptionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::SubscriptionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
Summary information for a flat-rate pricing subscription, as returned by list operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies this subscription.
-
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
-
#e_tag ⇒ String
The entity tag for concurrency control.
-
#plan_family ⇒ String
The pricing plan family for the subscription, such as
CloudFront. -
#plan_tier ⇒ String
The current tier level of the pricing plan.
-
#resource_arns ⇒ Array<String>
The ARNs of the AWS resources covered by this subscription.
-
#scheduled_change ⇒ Types::ScheduledChange
A pending change that will take effect at the end of the current billing period, if any.
-
#status ⇒ String
The current status of the subscription.
-
#status_reason ⇒ String
A human-readable explanation of the current status, present when additional context is available.
-
#updated_at ⇒ Time
The date and time when the subscription was last modified, in ISO 8601 format.
-
#usage_level ⇒ String
The usage level within the plan tier.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies this subscription.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time when the subscription was created, in ISO 8601 format.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#e_tag ⇒ String
The entity tag for concurrency control. Pass this value in the
If-Match header when making changes to this subscription.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#plan_family ⇒ String
The pricing plan family for the subscription, such as CloudFront.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#plan_tier ⇒ String
The current tier level of the pricing plan.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
The ARNs of the AWS resources covered by this subscription.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#scheduled_change ⇒ Types::ScheduledChange
A pending change that will take effect at the end of the current billing period, if any.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the subscription.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
A human-readable explanation of the current status, present when additional context is available.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time when the subscription was last modified, in ISO 8601 format.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |
#usage_level ⇒ String
The usage level within the plan tier.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 627 class SubscriptionSummary < Struct.new( :arn, :plan_family, :plan_tier, :usage_level, :scheduled_change, :status, :status_reason, :resource_arns, :created_at, :updated_at, :e_tag) SENSITIVE = [] include Aws::Structure end |