Class: Aws::PricingPlanManager::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PricingPlanManager::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pricingplanmanager/types.rb
Overview
The request failed a business rule validation. For example, the specified resource might already be associated with another subscription, or the subscription might not be in the required state for this operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
The identifier of the resource that failed validation.
Instance Attribute Details
#message ⇒ String
729 730 731 732 733 734 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 729 class ValidationException < Struct.new( :message, :resource_id) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The identifier of the resource that failed validation.
729 730 731 732 733 734 |
# File 'lib/aws-sdk-pricingplanmanager/types.rb', line 729 class ValidationException < Struct.new( :message, :resource_id) SENSITIVE = [] include Aws::Structure end |